@@ -19,7 +19,10 @@ class Backend(BaseBackend):
 
     def store_result(self, task_id, result, status):
         """Store task result and status."""
-        result = self.prepare_result(result)
+        if status == "DONE":
+            result = self.prepare_result(result)
+        elif status == "FAILURE":
+            result = self.prepare_exception(result)
         meta = {"status": status, "result": pickle.dumps(result)}
         cache.set(self._cache_key(task_id), meta)
 
@@ -29,7 +32,11 @@ class Backend(BaseBackend):
 
     def get_result(self, task_id):
         """Get the result of a task."""
-        return self._get_task_meta_for(self, task_id)["result"]
+        meta = self._get_task_meta_for(self, task_id)
+        if meta["status"] == "FAILURE":
+            return self.exception_to_python(meta["result"])
+        else:
+            return meta["result"]
 
     def is_done(self, task_id):
         """Returns ``True`` if the task has been executed successfully."""
