@@ -9,10 +9,13 @@ class Backend(BaseBackend):
     def __init__(self, *args, **kwargs):
         super(Backend, self).__init__(*args, **kwargs)
         self._cache = {}
-   
+
     def store_result(self, task_id, result, status):
         """Mark task as done (executed)."""
-        result = self.prepare_result(result)
+        if status == "DONE":
+            result = self.prepare_result(result)
+        elif status == "FAILURE":
+            result = self.prepare_exception(result)
         return TaskMeta.objects.store_result(task_id, result, status)
 
     def is_done(self, task_id):
@@ -25,7 +28,11 @@ class Backend(BaseBackend):
 
     def get_result(self, task_id):
         """Get the result for a task."""
-        return self._get_task_meta_for(task_id).result
+        meta = self._get_task_meta_for(task_id)
+        if meta.status == "FAILURE":
+            return self.exception_to_python(meta.result)
+        else:
+            return meta.result
 
     def _get_task_meta_for(self, task_id):
         if task_id in self._cache:
