@@ -15,7 +15,6 @@ try:
 except ImportError:
     import pickle
 
-    
 
 class Backend(BaseBackend):
     """Tokyo Cabinet based task backend store.
@@ -33,7 +32,13 @@ class Backend(BaseBackend):
     tyrant_port = None
 
     def __init__(self, tyrant_host=None, tyrant_port=None):
-        self.tyrant_host = kwargs.get("tyrant_host", 
+        """Initialize Tokyo Tyrant backend instance.
+
+        Raises :class:`django.core.exceptions.ImproperlyConfigured` if
+        :setting:`TT_HOST` or :setting:`TT_PORT` is not set.
+
+        """
+        self.tyrant_host = kwargs.get("tyrant_host",
                             getattr(settings, "TT_HOST", self.tyrant_host))
         self.tyrant_port = kwargs.get("tyrant_port",
                             getattr(settings, "TT_PORT", self.tyrant_port))
@@ -43,7 +48,7 @@ class Backend(BaseBackend):
                 "set the TT_HOST and TT_PORT settings in your settings.py")
         super(Backend, self).__init__(*args, **kwargs)
         self._cache = {}
-    
+
     def get_server(self):
         """Get :class:`pytyrant.PyTyrant`` instance with the current
         server configuration."""
@@ -54,7 +59,10 @@ class Backend(BaseBackend):
 
     def store_result(self, task_id, result, status):
         """Store task result and status."""
-        result = self.prepare_result(result)
+        if status == "DONE":
+            result = self.prepare_result(result)
+        elif status == "FAILURE":
+            result = self.prepare_exception(result)
         meta = {"status": status, "result": pickle.dumps(result)}
         self.get_server()[self._cache_key(task_id)] = serialize(meta)
 
@@ -64,7 +72,11 @@ class Backend(BaseBackend):
 
     def get_result(self, task_id):
         """Get the result of a task."""
-        return self._get_task_meta_for(self, task_id)["result"]
+        meta = self._get_task_meta_for(self, task_id)
+        if meta["status"] == "FAILURE":
+            return self.exception_to_python(meta["result"])
+        else:
+            return meta["result"]
 
     def is_done(self, task_id):
         """Returns ``True`` if the task executed successfully."""
