@@ -1,4 +1,8 @@
-"""celery.messaging"""
+"""
+
+Sending and Receiving Messages
+
+"""
 from carrot.messaging import Publisher, Consumer
 from celery import conf
 import uuid
@@ -6,11 +10,11 @@ import uuid
 
 class NoProcessConsumer(Consumer):
     """A consumer that raises an error if used with wait callbacks (i.e.
-    it doesn't support ``carrot.messaging.Consumer.wait``)."""
-    
+    it doesn't support :meth:`carrot.messaging.Consumer.wait``)."""
+
     def receive(self, message_data, message):
         raise NotImplementedError(
-                "Don't use process_next() or wait() with the TaskConsumer!")
+                "This consumer doesn't support process_next() or wait()")
 
 
 class TaskPublisher(Publisher):
@@ -23,13 +27,12 @@ class TaskPublisher(Publisher):
         return self._delay_task(task_name=task_name, args=task_args,
                                 kwargs=task_kwargs)
 
-
     def delay_task_in_set(self, task_name, taskset_id, task_args,
             task_kwargs):
         """Delay a task which part of a task set."""
         return self._delay_task(task_name=task_name, part_of_set=taskset_id,
                                 args=task_args, kwargs=task_kwargs)
-    
+
     def requeue_task(self, task_name, task_id, task_args, task_kwargs,
             part_of_set=None):
         """Requeue a failed task."""
