@@ -1,18 +1,28 @@
-"""celery.result"""
+"""
+
+Asynchronous result types.
+
+"""
 from celery.backends import default_backend
 
 
 class BaseAsyncResult(object):
-    """Base class for pending result, takes ``backend`` argument.
-    
+    """Base class for pending result, supports custom
+    task meta :attr:`backend`
+
+    :param task_id: see :attr:`task_id`.
+
+    :param backend: see :attr:`backend`.
+
+
     .. attribute:: task_id
 
         The unique identifier for this task.
 
     .. attribute:: backend
-       
+
         The task result backend used.
-    
+
     """
 
     def __init__(self, task_id, backend):
@@ -21,42 +31,48 @@ class BaseAsyncResult(object):
 
     def is_done(self):
         """Returns ``True`` if the task executed successfully.
-        
+
         :rtype: bool
-        
+
         """
         return self.backend.is_done(self.task_id)
 
     def get(self):
-        """Alias to ``wait``."""
+        """Alias to :meth:`wait`."""
         return self.wait()
 
     def wait(self, timeout=None):
-        """Return the result when it arrives.
-        
-        If timeout is not ``None`` and the result does not arrive within
-        ``timeout`` seconds then ``celery.backends.base.TimeoutError`` is
-        raised. If the remote call raised an exception then that exception
-        will be reraised by get()."""
+        """Wait for task, and return the result when it arrives.
+
+        :keyword timeout: How long to wait in seconds, before the
+            operation times out.
+
+        :raises celery.timer.TimeoutError: if ``timeout`` is not ``None`` and
+            the result does not arrive within ``timeout`` seconds.
+
+        If the remote call raised an exception then that
+        exception will be re-raised.
+
+        """
         return self.backend.wait_for(self.task_id, timeout=timeout)
 
     def ready(self):
         """Returns ``True`` if the task executed successfully, or raised
         an exception. If the task is still pending, or is waiting for retry
         then ``False`` is returned.
-        
-        :rtype: bool 
+
+        :rtype: bool
 
         """
         status = self.backend.get_status(self.task_id)
         return status != "PENDING" or status != "RETRY"
 
     def successful(self):
-        """Alias to ``is_done``."""
+        """Alias to :meth:`is_done`."""
         return self.is_done()
 
     def __str__(self):
-        """str(self) -> self.task_id"""
+        """``str(self)`` -> ``self.task_id``"""
         return self.task_id
 
     def __repr__(self):
@@ -64,28 +80,59 @@ class BaseAsyncResult(object):
 
     @property
     def result(self):
-        """The tasks resulting value."""
+        """When the task has been executed, this contains the return value.
+
+        If the task raised an exception, this will be the exception instance.
+
+        """
         if self.status == "DONE" or self.status == "FAILURE":
             return self.backend.get_result(self.task_id)
         return None
 
     @property
     def status(self):
-        """The current status of the task."""
+        """The current status of the task.
+
+        Can be one of the following:
+
+            *PENDING*
+
+                The task is waiting for execution.
+
+            *RETRY*
+
+                The task is to be retried, possibly because of failure.
+
+            *FAILURE*
+
+                The task raised an exception, or has been retried more times
+                than its limit. The :attr:`result` attribute contains the
+                exception raised.
+
+            *DONE*
+
+                The task executed successfully. The :attr:`result` attribute
+                contains the resulting value.
+
+        """
         return self.backend.get_status(self.task_id)
 
 
 class AsyncResult(BaseAsyncResult):
     """Pending task result using the default backend.
 
-    .. attribute:: task_id
+    :param task_id: see :attr:`task_id`.
+
     
+    .. attribute:: task_id
+
         The unique identifier for this task.
 
     .. attribute:: backend
-    
-        Instance of ``celery.backends.DefaultBackend``.
+
+        Instance of :class:`celery.backends.DefaultBackend`.
 
     """
+
     def __init__(self, task_id):
         super(AsyncResult, self).__init__(task_id, backend=default_backend)
