@@ -7,10 +7,11 @@ from celery import task
 from celery import registry
 from celery.log import setup_logger
 from celery import messaging
+from celery.backends import default_backend
 
 
-# Task run functions can't be closures/lambdas, as they're pickled.
 def return_True(self, **kwargs):
+    # Task run functions can't be closures/lambdas, as they're pickled.
     return True
 
 
@@ -48,6 +49,7 @@ class TestCeleryTasks(unittest.TestCase):
             self.assertEquals(task_kwargs.get(arg_name), arg_value)
 
     def test_incomplete_task_cls(self):
+
         class IncompleteTask(task.Task):
             name = "c.unittest.t.itask"
 
@@ -61,7 +63,7 @@ class TestCeleryTasks(unittest.TestCase):
                 "Task class is callable()")
         self.assertTrue(T1()(),
                 "Task class runs run() when called")
-        
+
         # task without name raises NotImplementedError
         T2 = self.createTaskCls("T2")
         self.assertRaises(NotImplementedError, T2)
@@ -93,7 +95,7 @@ class TestCeleryTasks(unittest.TestCase):
 
         self.assertFalse(task.is_done(presult.task_id))
         self.assertFalse(presult.is_done())
-        task.mark_as_done(presult.task_id, result=None)
+        default_backend.mark_as_done(presult.task_id, result=None)
         self.assertTrue(task.is_done(presult.task_id))
         self.assertTrue(presult.is_done())
 
@@ -106,15 +108,15 @@ class TestTaskSet(unittest.TestCase):
 
     def test_counter_taskset(self):
         ts = task.TaskSet(IncrementCounterTask, [
-            {},
-            {"increment_by": 2},
-            {"increment_by": 3},
-            {"increment_by": 4},
-            {"increment_by": 5},
-            {"increment_by": 6},
-            {"increment_by": 7},
-            {"increment_by": 8},
-            {"increment_by": 9},
+            [[], {}],
+            [[], {"increment_by": 2}],
+            [[], {"increment_by": 3}],
+            [[], {"increment_by": 4}],
+            [[], {"increment_by": 5}],
+            [[], {"increment_by": 6}],
+            [[], {"increment_by": 7}],
+            [[], {"increment_by": 8}],
+            [[], {"increment_by": 9}],
         ])
         self.assertEquals(ts.task_name, IncrementCounterTask.name)
         self.assertEquals(ts.total, 9)
