@@ -7,7 +7,7 @@ from celery.log import setup_logger
 from celery.registry import tasks
 from celery.datastructures import TaskProcessQueue
 from celery.models import PeriodicTaskMeta
-from celery.task import mark_as_done, mark_as_failure
+from celery.backends import default_backend
 from celery.timer import EventTimer
 import multiprocessing
 import simplejson
@@ -25,28 +25,74 @@ class UnknownTask(Exception):
     ignored."""
 
 
-def jail(task_id, callable_, args, kwargs):
-    """Wraps the task in a jail which saves the status and result
-    of the task execution to the task meta backend.
-   
-    If the call results in an exception, it saves the exception as the task
-    result, and sets the task status to ``FAILURE``.
+def jail(task_id, func, args, kwargs):
+    """Wraps the task in a jail, which catches all exceptions, and 
+    saves the status and result of the task execution to the task
+    meta backend.
 
     If the call was successful, it saves the result to the task result
-    backend, and sets the task status to ``DONE``.
+    backend, and sets the task status to ``"DONE"``.
+
+    If the call results in an exception, it saves the exception as the task
+    result, and sets the task status to ``"FAILURE"``.
+
+    :param task_id: The id of the task.
+
+    :param func: Callable object to execute.
+
+    :param args: List of positional args to pass on to the function.
+
+    :param kwargs: Keyword arguments mapping to pass on to the function.
+
+    :returns: the function return value on success.
+
+    :returns: the exception instance on failure.
 
     """
     try:
-        result = callable_(*args, **kwargs)
-        mark_as_done(task_id, result)
-        return result
+        result = func(*args, **kwargs)
     except Exception, exc:
-        mark_as_failure(task_id, exc)
+        default_backend.mark_as_failure(task_id, exc)
         return exc
+    else:
+        default_backend.mark_as_done(task_id, result)
+        return result
 
 
 class TaskWrapper(object):
-    """Class defining a task to be run."""
+    """Class wrapping a task to be run.
+    
+    :param task_name: see :attr:`task_name`.
+
+    :param task_id: see :attr:`task_id`.
+
+    :param task_func: see :attr:`task_func`
+
+    :param args: see :attr:`args`
+
+    :param kwargs: see :attr:`kwargs`.
+
+    .. attribute:: task_name
+
+        Kind of task. Must be a name registered in the task registry.
+    
+    .. attribute:: task_id
+
+        UUID of the task.
+
+    .. attribute:: task_func
+
+        The tasks callable object.
+
+    .. attribute:: args
+
+        List of positional arguments to apply to the task.
+
+    .. attribute:: kwargs
+
+        Mapping of keyword arguments to apply to the task.
+    
+    """
 
     def __init__(self, task_name, task_id, task_func, args, kwargs):
         self.task_name = task_name
@@ -57,14 +103,14 @@ class TaskWrapper(object):
 
     @classmethod
     def from_message(cls, message):
-        """Create a TaskWrapper from a message returned by
-        :class:`celery.messaging.TaskConsumer`.
+        """Create a :class:`TaskWrapper` from a task message sent by
+        :class:`celery.messaging.TaskPublisher`.
+
+        :raises UnknownTask: if the message does not describe a task,
+            the message is also rejected.
+
+        :returns: :class:`TaskWrapper` instance.
 
-        If the message is not a proper task it raises
-        :class:`UnknownTask` exception.
-        
-        :rtype: :class:`TaskWrapper` instance.
-        
         """
         message_data = simplejson.loads(message.body)
         task_name = message_data["task"]
@@ -77,7 +123,7 @@ class TaskWrapper(object):
         task_func = tasks[task_name]
         return cls(task_name, task_id, task_func, args, kwargs)
 
-    def extend_kwargs_with_logging(self, loglevel, logfile):
+    def extend_with_default_kwargs(self, loglevel, logfile):
         """Extend the tasks keyword arguments with standard task arguments.
 
         These are ``logfile``, ``loglevel``, ``task_id`` and ``task_name``.
@@ -90,58 +136,80 @@ class TaskWrapper(object):
         task_func_kwargs.update(self.kwargs)
         return task_func_kwargs
 
-    def execute(self, loglevel, logfile):
-        """Execute the task in a ``jail()`` and store its result and status
-        in the task meta backend."""
-        task_func_kwargs = self.extend_kwargs_with_logging(loglevel, logfile)
+    def execute(self, loglevel=None, logfile=None):
+        """Execute the task in a :func:`jail` and store return value
+        and status in the task meta backend.
+       
+        :keyword loglevel: The loglevel used by the task.
+
+        :keyword logfile: The logfile used by the task.
+
+        """
+        task_func_kwargs = self.extend_with_default_kwargs(loglevel, logfile)
         return jail(self.task_id, [
                         self.task_func, self.args, task_func_kwargs])
 
-    def execute_using_pool(self, pool, loglevel, logfile):
-        """Like ``execute``, but using the ``multiprocessing`` pool.
-       
-        :rtype: :class:`multiprocessing.AsyncResult` instance.
+    def execute_using_pool(self, pool, loglevel=None, logfile=None):
+        """Like :meth:`execute`, but using the :mod:`multiprocessing` pool.
+
+        :param pool: A :class:`multiprocessing.Pool` instance.
+
+        :keyword loglevel: The loglevel used by the task.
+
+        :keyword logfile: The logfile used by the task.
+
+        :returns :class:`multiprocessing.AsyncResult` instance.
+
         """
-        task_func_kwargs = self.extend_kwargs_with_logging(loglevel, logfile)
+        task_func_kwargs = self.extend_with_default_kwargs(loglevel, logfile)
         return pool.apply_async(jail, [self.task_id, self.task_func,
                                        self.args, task_func_kwargs])
 
 
 class TaskDaemon(object):
     """Executes tasks waiting in the task queue.
+    
+    :param concurrency: see :attr:`concurrency`.
+    
+    :param logfile: see :attr:`logfile`.
+
+    :param loglevel: see :attr:`loglevel`.
+
+    :param queue_wakeup_after: see :attr:`queue_wakeup_after`.
+
 
     .. attribute:: concurrency
 
         The number of simultaneous processes doing work (default:
-        ``celery.conf.DAEMON_CONCURRENCY``)
+        :const:`celery.conf.DAEMON_CONCURRENCY`)
 
     .. attribute:: loglevel
 
-        The loglevel used (default: ``logging.INFO``)
+        The loglevel used (default: :const:`logging.INFO`)
 
     .. attribute:: logfile
 
         The logfile used, if no logfile is specified it uses ``stderr``
-        (default: ``celery.conf.DAEMON_LOG_FILE``).
+        (default: :const:`celery.conf.DAEMON_LOG_FILE`).
 
     .. attribute:: queue_wakeup_after
 
         The time it takes for the daemon to wake up after the queue is empty,
         so it can check for more work
-        (default: ``celery.conf.QUEUE_WAKEUP_AFTER``).
+        (default: :const:`celery.conf.QUEUE_WAKEUP_AFTER`).
 
     .. attribute:: empty_msg_emit_every
 
-        How often the daemon emits the ``Waiting for queue`` message.
+        How often the daemon emits the ``"Waiting for queue..."`` message.
         If this is ``None``, the message will never be logged.
-        (default: ``celery.conf.EMPTY_MSG_EMIT_EVERY``)
+        (default: :const:`celery.conf.EMPTY_MSG_EMIT_EVERY`)
 
     .. attribute:: logger
 
         The :class:`logging.Logger` instance used for logging.
 
     .. attribute:: pool
-        
+
         The :class:`multiprocessing.Pool` instance used.
 
     .. attribute:: task_consumer
@@ -154,7 +222,7 @@ class TaskDaemon(object):
     logfile = DAEMON_LOG_FILE
     queue_wakeup_after = QUEUE_WAKEUP_AFTER
     empty_msg_emit_every = EMPTY_MSG_EMIT_EVERY
-    
+
     def __init__(self, concurrency=None, logfile=None, loglevel=None,
             queue_wakeup_after=None):
         self.loglevel = loglevel or self.loglevel
@@ -169,27 +237,37 @@ class TaskDaemon(object):
 
     def reset_connection(self):
         """Reset the AMQP connection, and reinitialize the
-        :class:`celery.messaging.TaskConsumer` instance."""
+        :class:`celery.messaging.TaskConsumer` instance.
+       
+        Resets the task consumer in :attr:`task_consumer`.
+
+        """
         if self.task_consumer:
             self.task_consumer.connection.close()
         amqp_connection = DjangoAMQPConnection()
         self.task_consumer = TaskConsumer(connection=amqp_connection)
 
     def connection_diagnostics(self):
-        """Diagnose the AMQP connection, and reset if necessary."""
-        if not self.task_consumer.channel.connection:
+        """Diagnose the AMQP connection, and reset connection if
+        necessary."""
+        if hasattr(self.task_consumer, "backend"):
+            connection = self.task_consumer.backend.channel.connection
+        else:
+            connection = self.task_consumer.channel.connection
+
+        if not connection:
             self.logger.info(
                     "AMQP Connection has died, restoring connection.")
             self.reset_connection()
 
     def receive_message(self):
-        """Receive the next message from the Task consumer queue.
-       
+        """Receive the next message from the message broker.
+
         Tries to reset the AMQP connection if not available.
         Returns ``None`` if no message is waiting on the queue.
 
         :rtype: :class:`carrot.messaging.Message` instance.
-        
+
         """
         self.connection_diagnostics()
         message = self.task_consumer.fetch()
@@ -197,23 +275,14 @@ class TaskDaemon(object):
             message.ack()
         return message
 
-    def receive_message_cc(self):
-        """UNUSED."""
-        amqp_connection = DjangoAMQPConnection()
-        task_consumer = TaskConsumer(connection=amqp_connection)
-        message = task_consumer.fetch()
-        if message is not None:
-            message.ack()
-        amqp_connection.close()
-        return message
-
     def fetch_next_task(self):
         """Fetch the next task from the AMQP broker.
-       
-        Raises :class`EmptyQueue` exception if there is no messages
+
+        Raises :exc:`EmptyQueue` exception if there is no message
         waiting on the queue.
 
-        :rtype: :class:`TaskWrapper` instance.
+        :returns: :class:`TaskWrapper` instance.
+
         """
         message = self.receive_message()
         if message is None: # No messages waiting.
@@ -226,10 +295,10 @@ class TaskDaemon(object):
         return task, message
 
     def execute_next_task(self):
-        """Execute the next task on the queue using the multiprocessing
-        pool.
-        
-        Catches all exceptions and logs them with level ``logging.CRITICAL``. 
+        """Execute the next task on the queue using the multiprocessing pool.
+
+        Catches all exceptions and logs them with level
+        :const:`logging.CRITICAL`.
 
         """
         task, message = self.fetch_next_task()
@@ -240,13 +309,13 @@ class TaskDaemon(object):
         except Exception, error:
             self.logger.critical("Worker got exception %s: %s\n%s" % (
                 error.__class__, error, traceback.format_exc()))
-            return 
+            return
 
         return result, task.task_name, task.task_id
 
     def run_periodic_tasks(self):
         """Schedule all waiting periodic tasks for execution.
-       
+
         :rtype: list of :class:`celery.models.PeriodicTaskMeta` objects.
         """
         waiting_tasks = PeriodicTaskMeta.objects.get_waiting_tasks()
@@ -259,7 +328,7 @@ class TaskDaemon(object):
         pass
 
     def run(self):
-        """The worker server's main loop."""
+        """Starts the workers main loop."""
         results = TaskProcessQueue(self.concurrency, logger=self.logger,
                 done_msg="Task %(name)s[%(id)s] processed: %(return_value)s")
         log_wait = lambda: self.logger.info("Waiting for queue...")
@@ -288,5 +357,5 @@ class TaskDaemon(object):
                 self.logger.critical("Message queue raised %s: %s\n%s" % (
                              e.__class__, e, traceback.format_exc()))
                 continue
-           
+
             results.add(result, task_name, task_id)
